# Installation

Power-events has few dependencies:

* [MayPy](https://mletrone.github.io/maypy/): Pythonic Java Optional
* [typing-extensions](https://pypi.org/project/typing-extensions/): Backport of the standard library typing module.

## Install with pip

<!-- termynal -->
```bash
$ pip install power-events
---> 100%
installed!
```
!!! tip
    Don't forget to use a **virtual environment** when installing library,
    otherwise it will be installed on your global python environment.

## Install with UV

!!! information
    UV is a wonderful tool to manage your dependencies and packaging!
    I highly recommend checking it if you don't know [Learn more :octicons-link-external-16:](https://docs.astral.sh/uv/){:target="_blank"}

<!-- termynal -->
```bash
$ uv add power-events
---> 100%
Installing power-events
writing lock file
```

## Install with poetry

!!! information
    Poetry is a great tool to manage your dependencies and packaging.
    I highly recommend checking it if you don't know [Learn more :octicons-link-external-16:](https://python-poetry.org/docs/){:target="_blank"}


<!-- termynal -->
```bash
$ poetry add power-events
---> 100%
Installing power-events
writing lock file
```
